@@ -4,7 +4,7 @@ use parent qw(Alien::Base);
 use strict;
 use warnings;
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 1;
 
@@ -82,6 +82,10 @@ Michal Josef Špaček L<mailto:skim@cpan.org>
 
 L<http://skim.cz>
 
+=head1 CONTRIBUTORS
+
+Zakariyya Mughal L<zaki.mughal@gmail.com>
+
 =head1 LICENSE AND COPYRIGHT
 
 © 2022 Michal Josef Špaček
@@ -90,6 +94,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
